@@ -47,14 +47,11 @@
 #include <cstring>
 #include <fofi/FoFiTrueType.h>
 #include <fofi/FoFiType1C.h>
-#include <fstream>
-
-#include "Error.h"
-#include "Gfx.h"
-#include "GlobalParams.h"
-#include "Page.h"
-#include "XRef.h"
-#include "goo/gfile.h"
+#include <poppler/Error.h>
+#include <poppler/Gfx.h>
+#include <poppler/GlobalParams.h>
+#include <poppler/Page.h>
+#include <poppler/XRef.h>
 
 //========================================================================
 //
